"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOrSetCache = void 0;
const tslib_1 = require("tslib");
const find_cache_dir_1 = tslib_1.__importDefault(require("find-cache-dir"));
const path_1 = require("path");
const make_dir_1 = tslib_1.__importDefault(require("make-dir"));
const fs_1 = require("fs");
const util_1 = require("util");
const readFileAsync = util_1.promisify(fs_1.readFile);
const writeFileAsync = util_1.promisify(fs_1.writeFile);
let cacheDir;
function getCacheDir() {
    if (!cacheDir) {
        const path = find_cache_dir_1.default({ name: "kubernetes-models-read-input" });
        if (!path)
            throw new Error("failed to get the cache directory");
        cacheDir = path;
    }
    return cacheDir;
}
async function getOrSetCache(key, valueFn) {
    const path = path_1.join(getCacheDir(), key);
    try {
        return await readFileAsync(path, "utf8");
    }
    catch (err) {
        if (err.code !== "ENOENT")
            throw err;
    }
    const value = await valueFn();
    await make_dir_1.default(path_1.dirname(path));
    await writeFileAsync(path, value);
    return value;
}
exports.getOrSetCache = getOrSetCache;
//# sourceMappingURL=cache.js.map